OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Não é possível gravar no diretório \"config\"!",
    "See %s" : "Ver %s",
    "Sample configuration detected" : "Detetado exemplo de configuração",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detetado que a configuração de amostra foi copiada. Isso pode danificar a sua instalação e não é suportado. Por favor, leia a documentação antes de realizar mudanças no config.php",
    "The page could not be found on the server." : "Esta página não foi encontrada no servidor.",
    "Email verification" : "Verificação de e-mail",
    "Click the following button to confirm your email." : "Clique no botão a seguir para confirmar o seu e-mail.",
    "Click the following link to confirm your email." : "Clique na hiperligação a seguir para confirmar o seu e-mail.",
    "Confirm your email" : "Confirmar o seu e-mail",
    "Other activities" : "Outras atividades",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Enterprise bundle" : "Pacote Empresa",
    "Groupware bundle" : "Pacote Colaborativo",
    "Social sharing bundle" : "Pacote Partilha Social",
    "PHP %s or higher is required." : "Necessário PHP %s ou superior.",
    "PHP with a version lower than %s is required." : "É necessário um PHP com uma versão inferir a %s.",
    "%sbit or higher PHP required." : "Necessário PHP %sbit ou superior.",
    "The following architectures are supported: %s" : "As seguintes arquiteturas são suportadas: %s",
    "The following databases are supported: %s" : "As seguintes bases de dados são suportadas: %s",
    "The command line tool %s could not be found" : "Não foi encontrada a ferramenta de linha de comando %s",
    "The library %s is not available." : "A biblioteca %s não está disponível.",
    "The following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
    "Server version %s or higher is required." : "É necessária versão do servidor %s or superior. ",
    "Server version %s or lower is required." : "É necessária versão do servidor %s or inferior.",
    "Authentication" : "Autenticação",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "Invalid image" : "Imagem inválida",
    "Avatar image is not square" : "A imagem do avatar não é quadrada.",
    "Files" : "Ficheiros",
    "View profile" : "Visualizar perfil",
    "today" : "hoje",
    "tomorrow" : "Amanhã",
    "yesterday" : "ontem",
    "_in %n day_::_in %n days_" : ["em %n dia","em %n dias","em %n dias"],
    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
    "next month" : "Próximo mês",
    "last month" : "ultimo mês",
    "_in %n month_::_in %n months_" : ["em %n mês","em %n meses","em %n meses"],
    "_%n month ago_::_%n months ago_" : ["%n mês atrás","%n meses atrás","%n meses atrás"],
    "next year" : "Próximo ano",
    "last year" : "ano passado",
    "_in %n year_::_in %n years_" : ["dentro de%n ano","dentro de %n anos","dentro de %n anos"],
    "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás","%n anos atrás"],
    "_in %n hour_::_in %n hours_" : ["dentro de %n hora","dentro de %n horas","dentro de %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["%n hora atrás","%n horas atrás","%n horas atrás"],
    "_in %n minute_::_in %n minutes_" : ["dentro de %n minuto","dentro de %n minutos","dentro de %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuto atrás","%n minutos atrás","%n minutos atrás"],
    "in a few seconds" : "em breves segundos",
    "seconds ago" : "Minutos atrás",
    "Empty file" : "Ficheiro vazio",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Módulo com ID: %s não existe. Por favor ative-o nas definições da aplicação ou contacte o administrador.",
    "Dot files are not allowed" : "Ficheiros dot não são permitidos",
    "%1$s (renamed)" : "%1$s (renomeado)",
    "renamed file" : "ficheiro renomeado",
    "File already exists" : "O ficheiro já existe",
    "Invalid path" : "Caminho inválido!",
    "Failed to create file from template" : "Erro ao criar o ficheiro a partir do modelo",
    "Templates" : "Modelos",
    "Filename contains at least one invalid character" : "Nome ficheiro contém pelo menos um carácter inválido",
    "Empty filename is not allowed" : "Não é permitido um ficheiro sem nome",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "A app \"%s\" não pode ser instalada porque o ficheiro appinfo não pode ser lido.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "A aplicação \"%s\" não pode ser instada porque não é compatível com esta versão do servidor.",
    "__language_name__" : "Português",
    "This is an automatically sent email, please do not reply." : "Este e-mail foi enviado automaticamente, por favor não responda a este e-mail.",
    "Appearance and accessibility" : "Aspeto e acessibilidade",
    "Apps" : "Apps",
    "Settings" : "Definições",
    "Log out" : "Sair",
    "Accounts" : "Contas",
    "Email" : "E-mail",
    "Mail %s" : "Mensagem para %s",
    "Phone" : "Telefone",
    "Call %s" : "Ligar a %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Visualizar %s no Twitter",
    "Website" : "Website",
    "Visit %s" : "Visite %s",
    "Address" : "Endereço",
    "Profile picture" : "Imagem do perfil",
    "About" : "Sobre",
    "Display name" : "Nome a exibir",
    "Headline" : "Título ",
    "Role" : "Função",
    "Additional settings" : "Definições adicionais",
    "You need to enter details of an existing account." : "Precisa de introduzir detalhes de uma conta existente.",
    "Oracle connection could not be established" : "Não foi possível estabelecer a ligação Oracle",
    "For the best results, please consider using a GNU/Linux server instead." : "Para um melhor resultado, utilize antes o servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que a instância %s está a ser executada num ambiente PHP de 32-bits e o open_basedir foi configurado no php.ini. Isto levará a problemas com ficheiros de tamanho superior a 4 GB e é altamente desencorajado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a definição open_basedir do seu php.ini ou altere o seu PHP para 64-bits.",
    "Set an admin password." : "Definia uma palavra-passe de administrador.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Ao partilhar a interface %s deve implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Não foi encontrada a partilha da interface %s",
    "Sharing backend for %s not found" : "Não foi encontrada a partilha da interface para %s",
    "%1$s shared %2$s with you" : "%1$s partilhou %2$s consigo",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
    "%1$s shared %2$s with you and wants to add" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
    "%s added a note to a file shared with you" : "»%s« adicionou uma nota a um ficheiro partilhado consigo",
    "Unknown share type" : "Tipo de partilha desconhecido",
    "You are not allowed to share %s" : "Não está autorizado a partilhar %s",
    "Cannot increase permissions of %s" : "Não é possível aumentar as permissões de %s",
    "Expiration date is in the past" : "A data de expiração está no passado",
    "The requested share does not exist anymore" : "A partilha requisitada já não existe",
    "Could not find category \"%s\"" : "Não foi encontrado a categoria \"%s\"",
    "Sunday" : "Domingo",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Seg.",
    "Tue." : "Ter.",
    "Wed." : "Qua.",
    "Thu." : "Qui.",
    "Fri." : "Sex.",
    "Sat." : "Sáb.",
    "Su" : "Dom",
    "Mo" : "Seg",
    "Tu" : "Ter",
    "We" : "Qua",
    "Th" : "Qui",
    "Fr" : "Sex",
    "Sa" : "Sáb",
    "January" : "Janeiro",
    "February" : "Fevereiro",
    "March" : "Março",
    "April" : "Abril",
    "May" : "Maio",
    "June" : "Junho",
    "July" : "Julho",
    "August" : "Agosto",
    "September" : "Setembro",
    "October" : "Outubro",
    "November" : "Novembro",
    "December" : "Dezembro",
    "Jan." : "Jan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Out.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "A valid password must be provided" : "Deve ser fornecida uma palavra-passe válida",
    "Login canceled by app" : "Sessão cancelada pela app",
    "a safe home for all your data" : "Um lugar seguro para todos os seus dados",
    "Application is not enabled" : "A aplicação não está ativada",
    "Authentication error" : "Erro na autenticação",
    "Token expired. Please reload page." : "O token expirou. Por favor recarregue a página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhuma base de dados de drivers (sqlite, mysql, or postgresql) instaladas.",
    "Cannot write into \"config\" directory." : "Não é possível escrever na diretoria \"config\".",
    "Your data directory is not writable." : "A sua diretoria de dados é só de leitura.",
    "PHP module %s not installed." : "O modulo %s PHP não está instalado.",
    "Please ask your server administrator to install the module." : "Por favor pergunte ao seu administrador do servidor para instalar o modulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Configuração PHP \"%s\" não está definida para \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar esta definição no php.ini fará com que o Nextcloud inicie novamente",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado a remover blocos doc em linha. Isto vai tornar algumas aplicações básicas inacessíveis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto é provavelmente causado por uma cache/acelerador como o Zend OPcache or eAcelerador.",
    "PHP modules have been installed, but they are still listed as missing?" : "Os módulos PHP foram instalados,   mas eles ainda estão listados como desaparecidos?",
    "Please ask your server administrator to restart the web server." : "Pro favor pergunte ao seu administrador do servidor para reiniciar o servidor da internet.",
    "Your data directory is invalid." : "A sua diretoria de dados é inválida.",
    "Action \"%s\" not supported or implemented." : "Ação \"%s\" não suportada ou implementada.",
    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter o tipo de bloqueio %d em \"%s\".",
    "Storage unauthorized. %s" : "Armazenamento desautorizado. %s",
    "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
    "Storage connection error. %s" : "Erro de ligação ao armazenamento. %s",
    "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
    "Storage connection timeout. %s" : "A ligação ao armazenamento expirou. %s",
    "Images" : "Imagens",
    "Chat" : "Chat",
    "Text" : "Texto",
    "Summary" : "Resumo",
    "Translate" : "Traduzir",
    "Organisation" : "Organização"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
